import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
  * Demonstrates how to add a binding and its attributes to a context.
  * (Use Rebind example to overwrite binding; use Unbind to remove binding.)
  *
  * Need schema checking to be turned off on server (unless you add
  * a fruit objectclass to the schema).
  *
  * usage: java Bind
  */

class Bind {
    public static void main(String[] args) {

	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	try {
	    // Create the initial context
	    DirContext ctx = new InitialDirContext(env);

	    // Create object to be bound
	    Fruit fruit = new Fruit("orange");

	    // Create attributes to be associated with object
	    Attributes attrs = new BasicAttributes(true); // case-ignore
	    Attribute objclass = new BasicAttribute("objectclass");
	    objclass.add("top");
	    objclass.add("fruit");
	    attrs.put(objclass);
	    attrs.put("color", "orange");
	    attrs.put("flavor", "sweet");

	    // Perform bind
	    ctx.bind("cn=favorite, cn=Fruits", fruit, attrs);

	    // Check that it is bound
	    Object obj = ctx.lookup("cn=favorite, cn=Fruits");
	    System.out.println(obj);

	    // Get its attributes
	    Attributes retattrs = ctx.getAttributes("cn=favorite, cn=Fruits");
	    GetattrsAll.printAttrs(retattrs);

	} catch (NamingException e) {
	    System.out.println("Operation failed: " + e);
	}
    }
}
